A function to obtain annual maxima (AMAX) data using the NRFA API
Source:R/get_winfapapi.R
get_amax.RdThe function queries the NRFA API for the .AM file similar to the WINFAP file for a given stations. It then processes the file in a fashion similar to read_amax.
Value
a data.frame with information on the annual maxima for the station with the following columns
- Station
NRFA station number (can be a vector of station numbers)
- WaterYear
the correct water year for the peak flow
- Date
date of maximum flow
- Flow
the maximum flow in m3/s
- Stage
the stage (height) reached by the river - this information is used to derive the flow via a rating curve
- Rejected
logical, if TRUE the water year has been flagged as rejected by the NRFA
See also
read_amax. Information on river flow gauging in the UK and the annual maxima can be found at the National River Flow Archive website https://nrfa.ceh.ac.uk
Examples
a40003 <- get_amax(40003) # the Medway at Teston / East Farleigh
multipleStations <- get_amax(c(40003, 42003))
names(multipleStations)
#> [1] "40003" "42003"
summary(multipleStations$`42003`)
#> Station WaterYear Date Flow
#> Min. :42003 Min. :1975 Min. :1976-09-30 21:00:00 Min. : 4.16
#> 1st Qu.:42003 1st Qu.:1987 1st Qu.:1988-03-08 21:48:45 1st Qu.:15.76
#> Median :42003 Median :2000 Median :2000-05-31 15:30:00 Median :21.10
#> Mean :42003 Mean :2000 Mean :2000-07-16 05:55:48 Mean :25.50
#> 3rd Qu.:42003 3rd Qu.:2012 3rd Qu.:2012-11-02 15:22:30 3rd Qu.:29.62
#> Max. :42003 Max. :2024 Max. :2024-11-27 14:30:00 Max. :81.18
#> Stage Rejected
#> Min. :-9999.000 Mode :logical
#> 1st Qu.: 1.244 FALSE:30
#> Median : 1.387 TRUE :20
#> Mean :-1398.569
#> 3rd Qu.: 1.622
#> Max. : 2.134