The function reads .CD3 files once these are in a local folder: these files contain information on the gauging station and on the catchment upstream the station.
Usage
read_cd3(station, loc_WinFapFiles = getwd())See also
Information on the .CD3 files and river flow gauging in the UK can be found at the National River Flow Archive website https://nrfa.ceh.ac.uk. Specific information on the catchment descriptors can be found at https://nrfa.ceh.ac.uk/data/about-data/catchment-information/feh-catchment-descriptors